##  AI Agent Governance Report
If you use the [AI Agent Hub](https://help.sap.com/docs/leanix/ea/ai-agent-hub?locale=en-US&state=PRODUCTION&version=CLOUD "Discover and manage AI agents across the organization."), you can track the approval status of AI agents segmented by application type with the predefined AI Agent Governance report. You can find this report in the AI Agents collection on the reports page.
Use radar rings to visualize the Approval State, and adjust the Ring Category to explore different dimensions of the data. The report indicates which AI agents are in Draft, Preview, Accepted, or Rejected status.
When AI agents are in the Draft state, collect key attributes for further assessment: usage, AI risk, business value, and the potential of related business capabilities. Once you've assessed these key attributes, move the status to In Preview, then accept or reject AI agents based on your defined criteria. For example, accept AI agents with low risk, high usage, and high business value.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio285779afd26546e6a619dbb612a506b6_LowRes.png)
AI Agents Governance Report
### Create a Portal for Approved AI Agents
To drive user adoption, create a portal for approved AI agents. With portals, users get an overview of available AI agents without signing in to SAP LeanIX. They can filter AI agents by business capabilities to find agents relevant to their domain, such as “Customer Relationship,” “Finance,” or “HR.” This approach enhances transparency and promotes adoption.
To learn how to configure portals, see [Portals](https://help.sap.com/docs/leanix/ea/portals?locale=en-US&state=PRODUCTION&version=CLOUD "Create customizable, secure entry points that provide non-IT users with curated enterprise architecture information, resources, and visual assets outside the main application.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioaf647d606a0b416eb905b0cac56b811b_LowRes.png)
Portal for Approved AI Agents
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
